pub struct ShowArgs {
pub feed_url: String,
pub id: String,
pub refresh: bool,
pub content: ContentArg,
pub max_content_chars: Option<usize>,
pub format: FormatArg,
}Fields
feed_url: StringFeed URL containing the item.
id: StringStable item id, raw guid, or item permalink URL (from a prior fetch). A guid is the
reliable key across different feed URLs (the id is namespaced by feed URL).
refresh: boolBypass the cache-first read and revalidate the live feed (may miss items that have rolled out of the feed window).
content: ContentArgContent extraction format.
max_content_chars: Option<usize>Truncate the item body to at most this many characters (flagged content_truncated).
format: FormatArgOutput format.