pub fn exit_code_for(output: &FetchOutput) -> i32Expand description
Determine the appropriate process exit code from a FetchOutput.
pub fn exit_code_for(output: &FetchOutput) -> i32Determine the appropriate process exit code from a FetchOutput.