pub struct DiscoveredFeed {
pub url: String,
pub feed_type: String,
pub title: Option<String>,
}Expand description
A feed discovered on a website’s homepage.
Fields
url: Stringfeed_type: String"rss" | "atom" | "json" | "unknown".
title: Option<String>Trait Implementations
Sourceimpl Clone for DiscoveredFeed
impl Clone for DiscoveredFeed
Sourcefn clone(&self) -> DiscoveredFeed
fn clone(&self) -> DiscoveredFeed
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DiscoveredFeed
impl Debug for DiscoveredFeed
Sourceimpl<'de> Deserialize<'de> for DiscoveredFeed
impl<'de> Deserialize<'de> for DiscoveredFeed
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DiscoveredFeed
impl JsonSchema for DiscoveredFeed
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DiscoveredFeed
impl RefUnwindSafe for DiscoveredFeed
impl Send for DiscoveredFeed
impl Sync for DiscoveredFeed
impl Unpin for DiscoveredFeed
impl UnsafeUnpin for DiscoveredFeed
impl UnwindSafe for DiscoveredFeed