pub struct Enclosure {
pub url: String,
pub mime: Option<String>,
pub length: Option<u64>,
}Expand description
A media attachment (podcast audio, image, etc.).
Fields
url: Stringmime: Option<String>length: Option<u64>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Enclosure
impl<'de> Deserialize<'de> for Enclosure
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Enclosure
impl JsonSchema for Enclosure
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for Enclosure
impl RefUnwindSafe for Enclosure
impl Send for Enclosure
impl Sync for Enclosure
impl Unpin for Enclosure
impl UnsafeUnpin for Enclosure
impl UnwindSafe for Enclosure