pub struct Warning {
pub feed_url: Option<String>,
pub code: String,
pub message: String,
}Expand description
A non-fatal data-quality note about a feed (the feed still parsed and produced items). Surfaces silent fallbacks an agent should know about — e.g. lower-fidelity content extraction, or items it cannot order by time.
Fields
feed_url: Option<String>The feed this warning pertains to, if applicable.
code: StringStable, machine-readable code (e.g. CONTENT_EXTRACTION_FALLBACK, UNDATED_ITEMS).
message: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Warning
impl<'de> Deserialize<'de> for Warning
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Warning
impl JsonSchema for Warning
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for Warning
impl RefUnwindSafe for Warning
impl Send for Warning
impl Sync for Warning
impl Unpin for Warning
impl UnsafeUnpin for Warning
impl UnwindSafe for Warning